# -*- ruby encoding: utf-8 -*-
#############################################################
# This file was automatically generated on 2019-08-23.      #
#                                                           #
# Ruby Bindings Version 2.1.23                              #
#                                                           #
# If you have a bugfix for this file and want to commit it, #
# please fix the bug in the generator. You can find a link  #
# to the generators git repository on tinkerforge.com       #
#############################################################

module Tinkerforge
  # Measures UV light
  class BrickletUVLight < Device
    DEVICE_IDENTIFIER = 265 # :nodoc:
    DEVICE_DISPLAY_NAME = 'UV Light Bricklet' # :nodoc:

    # This callback is triggered periodically with the period that is set by
    # BrickletUVLight#set_uv_light_callback_period. The parameter is the UV Light
    # intensity of the sensor.
    # 
    # The CALLBACK_UV_LIGHT callback is only triggered if the intensity has changed
    # since the last triggering.
    CALLBACK_UV_LIGHT = 8

    # This callback is triggered when the threshold as set by
    # BrickletUVLight#set_uv_light_callback_threshold is reached.
    # The parameter is the UV Light intensity of the sensor.
    # 
    # If the threshold keeps being reached, the callback is triggered periodically
    # with the period as set by BrickletUVLight#set_debounce_period.
    CALLBACK_UV_LIGHT_REACHED = 9

    FUNCTION_GET_UV_LIGHT = 1 # :nodoc:
    FUNCTION_SET_UV_LIGHT_CALLBACK_PERIOD = 2 # :nodoc:
    FUNCTION_GET_UV_LIGHT_CALLBACK_PERIOD = 3 # :nodoc:
    FUNCTION_SET_UV_LIGHT_CALLBACK_THRESHOLD = 4 # :nodoc:
    FUNCTION_GET_UV_LIGHT_CALLBACK_THRESHOLD = 5 # :nodoc:
    FUNCTION_SET_DEBOUNCE_PERIOD = 6 # :nodoc:
    FUNCTION_GET_DEBOUNCE_PERIOD = 7 # :nodoc:
    FUNCTION_GET_IDENTITY = 255 # :nodoc:

    THRESHOLD_OPTION_OFF = 'x' # :nodoc:
    THRESHOLD_OPTION_OUTSIDE = 'o' # :nodoc:
    THRESHOLD_OPTION_INSIDE = 'i' # :nodoc:
    THRESHOLD_OPTION_SMALLER = '<' # :nodoc:
    THRESHOLD_OPTION_GREATER = '>' # :nodoc:

    # Creates an object with the unique device ID <tt>uid</tt> and adds it to
    # the IP Connection <tt>ipcon</tt>.
    def initialize(uid, ipcon)
      super uid, ipcon

      @api_version = [2, 0, 0]

      @response_expected[FUNCTION_GET_UV_LIGHT] = RESPONSE_EXPECTED_ALWAYS_TRUE
      @response_expected[FUNCTION_SET_UV_LIGHT_CALLBACK_PERIOD] = RESPONSE_EXPECTED_TRUE
      @response_expected[FUNCTION_GET_UV_LIGHT_CALLBACK_PERIOD] = RESPONSE_EXPECTED_ALWAYS_TRUE
      @response_expected[FUNCTION_SET_UV_LIGHT_CALLBACK_THRESHOLD] = RESPONSE_EXPECTED_TRUE
      @response_expected[FUNCTION_GET_UV_LIGHT_CALLBACK_THRESHOLD] = RESPONSE_EXPECTED_ALWAYS_TRUE
      @response_expected[FUNCTION_SET_DEBOUNCE_PERIOD] = RESPONSE_EXPECTED_TRUE
      @response_expected[FUNCTION_GET_DEBOUNCE_PERIOD] = RESPONSE_EXPECTED_ALWAYS_TRUE
      @response_expected[FUNCTION_GET_IDENTITY] = RESPONSE_EXPECTED_ALWAYS_TRUE

      @callback_formats[CALLBACK_UV_LIGHT] = 'L'
      @callback_formats[CALLBACK_UV_LIGHT_REACHED] = 'L'

    end

    # Returns the UV light intensity of the sensor, the intensity is given
    # in 1/10 mW/m². The sensor has already weighted the intensity with the erythemal
    # action spectrum to get the skin-affecting irradiation.
    # 
    # To get UV index you just have to divide the value by 250. For example, a UV
    # light intensity of 500 is equivalent to an UV index of 2.
    # 
    # If you want to get the intensity periodically, it is recommended to use the
    # CALLBACK_UV_LIGHT callback and set the period with
    # BrickletUVLight#set_uv_light_callback_period.
    def get_uv_light
      send_request FUNCTION_GET_UV_LIGHT, [], '', 4, 'L'
    end

    # Sets the period in ms with which the CALLBACK_UV_LIGHT callback is triggered
    # periodically. A value of 0 turns the callback off.
    # 
    # The CALLBACK_UV_LIGHT callback is only triggered if the intensity has changed since
    # the last triggering.
    # 
    # The default value is 0.
    def set_uv_light_callback_period(period)
      send_request FUNCTION_SET_UV_LIGHT_CALLBACK_PERIOD, [period], 'L', 0, ''
    end

    # Returns the period as set by BrickletUVLight#set_uv_light_callback_period.
    def get_uv_light_callback_period
      send_request FUNCTION_GET_UV_LIGHT_CALLBACK_PERIOD, [], '', 4, 'L'
    end

    # Sets the thresholds for the CALLBACK_UV_LIGHT_REACHED callback.
    # 
    # The following options are possible:
    # 
    #  "Option", "Description"
    # 
    #  "'x'",    "Callback is turned off"
    #  "'o'",    "Callback is triggered when the intensity is *outside* the min and max values"
    #  "'i'",    "Callback is triggered when the intensity is *inside* the min and max values"
    #  "'<'",    "Callback is triggered when the intensity is smaller than the min value (max is ignored)"
    #  "'>'",    "Callback is triggered when the intensity is greater than the min value (max is ignored)"
    # 
    # The default value is ('x', 0, 0).
    def set_uv_light_callback_threshold(option, min, max)
      send_request FUNCTION_SET_UV_LIGHT_CALLBACK_THRESHOLD, [option, min, max], 'k L L', 0, ''
    end

    # Returns the threshold as set by BrickletUVLight#set_uv_light_callback_threshold.
    def get_uv_light_callback_threshold
      send_request FUNCTION_GET_UV_LIGHT_CALLBACK_THRESHOLD, [], '', 9, 'k L L'
    end

    # Sets the period in ms with which the threshold callbacks
    # 
    # * CALLBACK_UV_LIGHT_REACHED,
    # 
    # are triggered, if the thresholds
    # 
    # * BrickletUVLight#set_uv_light_callback_threshold,
    # 
    # keep being reached.
    # 
    # The default value is 100.
    def set_debounce_period(debounce)
      send_request FUNCTION_SET_DEBOUNCE_PERIOD, [debounce], 'L', 0, ''
    end

    # Returns the debounce period as set by BrickletUVLight#set_debounce_period.
    def get_debounce_period
      send_request FUNCTION_GET_DEBOUNCE_PERIOD, [], '', 4, 'L'
    end

    # Returns the UID, the UID where the Bricklet is connected to,
    # the position, the hardware and firmware version as well as the
    # device identifier.
    # 
    # The position can be 'a', 'b', 'c' or 'd'.
    # 
    # The device identifier numbers can be found :ref:`here <device_identifier>`.
    # |device_identifier_constant|
    def get_identity
      send_request FUNCTION_GET_IDENTITY, [], '', 25, 'Z8 Z8 k C3 C3 S'
    end

    # Registers a callback with ID <tt>id</tt> to the block <tt>block</tt>.
    def register_callback(id, &block)
      callback = block
      @registered_callbacks[id] = callback
    end
  end
end
